@@ -138,10 +138,10 @@ class init_tools(abc.ABC):
                     input_file_vars[k] = user_dict[k]
                 else:
                     raise TypeError(f'Input for {str(k)} not of the '
-                                    'right type in yaml configuration '
-                                    'file {self.input_file}. '
-                                    'Input type was {type(k).__name__}, '
-                                    'but needs to be {expected_type}.')
+                                    f'right type in yaml configuration '
+                                    f'file {self.input_file}. '
+                                    f'Input type was {type(k).__name__}, '
+                                    f'but needs to be {expected_type}.')
             else:
                 input_file_vars[k] = default_dict[k]['default']
 
@@ -164,10 +164,10 @@ class init_tools(abc.ABC):
                     input_file_vars[k] = user_dict[k]
                 else:
                     raise TypeError(f'Input for {str(k)} not of the '
-                                    'right type in yaml configuration '
-                                    'file {self.input_file}. '
-                                    'Input type was {type(k).__name__}, '
-                                    'but needs to be {expected_type}.')
+                                    f'right type in yaml configuration '
+                                    f'file {self.input_file}. '
+                                    f'Input type was {type(k).__name__}, '
+                                    f'but needs to be {expected_type}.')
             else:
                 # set using default value
                 input_file_vars[k] = v['default']
@@ -283,6 +283,16 @@ class init_tools(abc.ABC):
         Configure constants, including coordinates and distances, as well as
         environmental constants (gravity), and kernels for smoothing
         topography.
+
+        Some of the constants defined herein:
+            * `self.g`, gravitational acceleration
+            * `self.distances`, distance from cell `i,j` to neighbors (and self)  # noqa: E501
+            * `self.iwalk`, step distance cross domain to cell in indexed direction
+            * `self.jwalk`, step distance down domain to cell in indexed direction
+            * `self.ravel_walk`, flattened index distance to cell in indexed direction
+
+        Each of these attributes also has a `self.xxxxx_flat` sibling
+        attribute, which is simply the flattened version of that attribute.
         """
         _msg = 'Setting model constants'
         self.log_info(_msg, verbosity=1)
